@@ -91,6 +91,26 @@ def get_application_data(
     }
 
 
+def get_application_payment_data(**kwargs):
+    return {
+        'reason': 'PagamentoTari-3c819c1d-6587-448d-8ba4-3b6f23e87ed4',
+        'amount': '10',
+        'expire_at': '2022-04-28T11:18:41+02:00',
+        'split': [{'code': '2020/1', 'amount': '8', 'meta': {}}, {'code': '2020/2', 'amount': '2', 'meta': {}}],
+        'notify': {
+            'url': 'https://www2.stanzadelcittadino.it'
+            '/comune-di-bugliano/api/applications/3c819c1d-6587-448d-8ba4-3b6f23e87ed4/payment',
+            'method': 'POST',
+        },
+        'landing': {
+            'url': 'https://www2.stanzadelcittadino.it'
+            '/comune-di-bugliano/pratiche/3c819c1d-6587-448d-8ba4-3b6f23e87ed4/detail',
+            'method': 'GET',
+        },
+        **kwargs,
+    }
+
+
 def get_payment_event_data(**kwargs):
     return {
         'id': 'bb7044e4-066c-4bf7-915e-87ee97270eae',
@@ -179,6 +199,14 @@ def get_split_data(**kwargs):
     }
 
 
+def get_split_data_v2(**kwargs):
+    return {
+        'c_1': '14.00',
+        'c_2': None,
+        **kwargs,
+    }
+
+
 def get_payer_data(**kwargs):
     return {
         'type': 'human',
